/*
** Module   : LegacyField.java
** Abstract : Annotation used to set the legacy field name for a DMO property.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20131015 Created initial version.
** 002 OM  20140117 Added fieldId (support for runtime indexed access for fields).
** 003 VMN 20140120 Added format(), initial(), columnLabel(), label(), mandatory(),
**                  validateMessage(), validateExpression().
*/

package com.goldencode.p2j.persist;

import java.lang.annotation.*;

/**
 * Annotation definition to mark a DMO property with its legacy field name and attributes.
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface LegacyField
{
   /** COLUMN-LABEL attribute of this field. */
   String columnLabel() default "";

   /** DATA-TYPE attribute of this field. */
   String dataType();

   /**
    * The id of this field in the sequence of the fields of the buffer. It is needed by the
    * dynamic <code>bufferField(int)</code> attribute of the <code>BufferImpl</code> for
    * emulating the <code>BUFFER-FIELD(integer)</code> buffer handle attribute.
    */
   int fieldId();

   /** FORMAT attribute of this field. */
   String format() default "";

   /** INITIAL attribute of this field. */
   String initial() default "";

   /** LABEL attribute of this field. */
   String label() default "";

   /** MANDATORY attribute of this field. */
   boolean mandatory() default false;

   /** The name of the legacy field associated with a DMO property. */
   String name();

   /** VALIDATE-MESSAGE attribute of this field. */
   String validateMessage() default "";

   /** VALIDATE-EXPRESSION attribute of this field. */
   String validateExpression() default "";
}
